@@ -490,7 +490,7 @@ class DataTransformerForm(BaseInlineFormSet):
         super(DataTransformerForm, self).add_fields(form, index)
         dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self,
                                                              fk_name='parent',
-                                                             extra=1, exclude=['updated_at', 'created_at']
+                                                             extra=1, fields=['id','accessory','parent','type']
                                                              )
         form.nested_data_transformer_form = dataTransformerInlineFormset(
             instance=form.instance,
